unit Unit1;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, ExtCtrls, TeeProcs, TeEngine, Chart, Series, TeeComma;

type
  TForm1 = class(TForm)
    Chart1: TChart;
    TeeCommander1: TTeeCommander;
    procedure FormCreate(Sender: TObject);
    procedure Chart1Zoom(Sender: TObject);
    procedure Chart1Scroll(Sender: TObject);
    procedure Chart1UndoZoom(Sender: TObject);
  private
    { Private declarations }
    function GetMinMaxVisibleIndex(isMin: boolean; Series: TChartSeries): Integer;
    procedure UpdateMinMaxPoints;
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.dfm}

uses TeeGDIPlus, TeeThemes, TeePNG;

var MinVisibleIndex, MaxVisibleIndex: Integer;

procedure TForm1.FormCreate(Sender: TObject);
begin
  Chart1.Canvas:=TGDIPlusCanvas.Create;

  TBlackIsBackTheme.Create(Chart1).Apply;

  Chart1.View3D:=false;
  Chart1.AddSeries(TFastLineSeries).FillSampleValues(100);

  with Chart1.AddSeries(TPointSeries) do
  begin
    Chart1[1].AddNull('Min');
    Chart1[1].AddNull('Max');
    Marks.Visible:=true;
    ShowInLegend:=false;
  end;

  Chart1.Axes.Bottom.LabelStyle:=talValue;
  UpdateMinMaxPoints;
end;

function TForm1.GetMinMaxVisibleIndex(isMin: boolean; Series: TChartSeries): Integer;
var i: Integer;
begin
  result:=-1;
  for i:=Series.FirstValueIndex to Series.LastValueIndex do
  begin
    if ((Series.YValue[i] >= Series.GetVertAxis.Minimum) and
        (Series.YValue[i] <= Series.GetVertAxis.Maximum)) then
      if (isMin) then
      begin
        if ((result=-1) or (Series.YValue[i] < Series.YValue[result])) then result:=i;
      end
      else
        if ((result=-1) or (Series.YValue[i] > Series.YValue[result])) then result:=i;
  end;
end;

procedure TForm1.UpdateMinMaxPoints;
begin
  Chart1.Draw;

  MinVisibleIndex:=GetMinMaxVisibleIndex(true, Chart1[0]);
  MaxVisibleIndex:=GetMinMaxVisibleIndex(false, Chart1[0]);

  if (MinVisibleIndex>-1) then
  begin
    Chart1[1].ValueColor[0]:=clGreen;
    Chart1[1].XValue[0]:=Chart1[0].XValue[MinVisibleIndex];
    Chart1[1].YValue[0]:=Chart1[0].YValue[MinVisibleIndex];
  end
  else
    Chart1[1].SetNull(0);

  if (MaxVisibleIndex>-1) then
  begin
    Chart1[1].ValueColor[1]:=clBlue;
    Chart1[1].XValue[1]:=Chart1[0].XValue[MaxVisibleIndex];
    Chart1[1].YValue[1]:=Chart1[0].YValue[MaxVisibleIndex];
  end
  else
    Chart1[1].SetNull(1);
end;

procedure TForm1.Chart1Zoom(Sender: TObject);
begin
  UpdateMinMaxPoints;
end;

procedure TForm1.Chart1Scroll(Sender: TObject);
begin
  UpdateMinMaxPoints;
end;

procedure TForm1.Chart1UndoZoom(Sender: TObject);
begin
  UpdateMinMaxPoints;
end;

end.
